@@ -10,21 +10,11 @@ use crate::core::bytes::BufMut;
 use crate::core::Decoder;
 use crate::core::Encoder;
 use crate::core::Version;
-use crate::derive::Decode;
-use crate::derive::Encode;
 
 use crate::Offset;
 use crate::Size;
 use crate::record::Record;
 
-#[allow(deprecated)]
-#[deprecated(since = "0.5.1", note = "Use 'MemoryRecords' instead")]
-pub type DefaultBatchRecords = Vec<crate::record::DefaultRecord>;
-
-#[allow(deprecated)]
-#[deprecated(since = "0.5.1", note = "Use 'Batch' instead")]
-pub type DefaultBatch = Batch<DefaultBatchRecords>;
-
 pub trait BatchRecords: Default + Debug + Encoder + Decoder {
     /// how many bytes does record wants to process
     fn remainder_bytes(&self, remainder: usize) -> usize {
@@ -222,12 +212,15 @@ where
     }
 }
 
-#[derive(Debug, Decode, Encode)]
+#[derive(Debug, Decoder, Encoder)]
 pub struct BatchHeader {
     pub partition_leader_epoch: i32,
     pub magic: i8,
     pub crc: u32,
     pub attributes: i16,
+    /// Indicates the count from the beginning of the batch to the end
+    ///
+    /// Adding this to the base_offset will give the offset of the last record in this batch
     pub last_offset_delta: i32,
     pub first_timestamp: i64,
     pub max_time_stamp: i64,
